@@ -107,7 +107,7 @@ class TLPClient():
     TLPClient class.
     """
 
-    TLP_VERSION = "3.12.0"
+    TLP_VERSION = "3.X"
     API_SPEECH = "speech"
     API_TEXT = "text"
     API_WEB = "web"
@@ -239,8 +239,7 @@ class TLPClient():
             if self.ret_content_type.find("application/json") >= 0:
                 self.ret_data = json.loads(self._response.content)
             else:
-                #self.ret_data = self._response.content
-                self.ret_data = self._response.text
+                self.ret_data = self._response.content.decode('utf-8')
         elif self._response.status_code == 400:
             raise APIBadRequest(self._response.content)
         elif self._response.status_code == 401:
@@ -260,9 +259,9 @@ class TLPClient():
                 par = {'data':data}
             else:
                 par = self.parameters
-            self._response = self._session.get(url=url,params=par)
+            self._response = self._session.get(url=url,params=par, verify=False)
         else:
-            self._response = self._session.post(url=url,data=json.dumps(self.parameters), headers={'Content-Type':'application/json'})
+            self._response = self._session.post(url=url,data=json.dumps(self.parameters), headers={'Content-Type':'application/json'}, verify=False)
         self._parse_response()
         self._last_api_call = interface
         if self.debug: self._generate_debug_info_api(url)
@@ -275,9 +274,9 @@ class TLPClient():
         if pkg != None:
             files = {'json':('data.json', json.dumps(self.parameters), 'application/json')}
             files['pkg'] = ('mp.zip', open(pkg, 'rb'), 'application/zip')
-            self._response = self._session.post(url=url,files=files)
+            self._response = self._session.post(url=url,files=files, verify=False)
         else:
-            self._response = self._session.post(url=url,data=json.dumps(self.parameters), headers={'Content-Type':'application/json'})
+            self._response = self._session.post(url=url,data=json.dumps(self.parameters), headers={'Content-Type':'application/json'}, verify=False)
             
         self._parse_response()
         self._last_api_call = interface
@@ -582,6 +581,7 @@ class TLPStandardClient(TLPClient):
       self._call("list")
    
 
+
     def api_langs(self, oid, vhash=None, su=None, use_req_key=False, req_key_lifetime=1):
       """ Performs an API call to the /langs interface:
 
@@ -1258,6 +1258,27 @@ class TLPSpeechClient(TLPStandardClient):
             self.manifest['callback']['params'] = params
 
 
+    def api_list_fullinfo(self, limit=10, page=1, su=None):
+      """ Performs an API call to the /list_fullinfo interface:
+
+	  > *Get a list of all existing audios and videos in the TLP Database, plus
+             their metadata, captions available, and media file locations. Objects are
+             sorted by ingestion date, from the more recent to the oldest.*
+
+          Queries to this interface are limited to **_limit_** results. Use **_page_** > 1 
+          to retrieve further results, if any. 
+
+	  The **_su_** (*substitute user*) option can be used by Admin users
+          to be identified as another existing API user at the TLP API.
+      """
+      self._reset()
+      self.parameters['limit'] = limit
+      self.parameters['page'] = page
+      if su != None: self.parameters['su'] = su
+      self._set_auth_parameters_secret_key()
+      self._call("list_fullinfo")
+ 
+
     def api_get(self, oid, lang, form=None, seldata=None, segfilt=None, session_id=None, pending_revs=None, vhash=None, su=None, use_req_key=False, req_key_lifetime=1):
       """ Performs an API call to the /get interface:
 
@@ -1447,7 +1468,32 @@ class TLPSpeechClient(TLPStandardClient):
           else:
               self._set_auth_parameters_secret_key()
       self._call("mod")
-  
+
+    def api_active_sessions(self, oid, vhash=None, su=None, use_req_key=False, req_key_lifetime=1):
+      """ Performs an API call to the /speech/active_sessions interface:
+
+          > *Returns a list of active edit sessions involving a given media ID..*
+      
+          The **_oid_** parameter is the Media ID. 
+
+          Optionally, a media hash value can be provided using the optional **_vhash_** parameter.
+
+	  If **_use_req_key_** *= True*, the API call will be performed using a
+          valid *Request Key* as authentication token instead of the *Secret Key*. **_req_key_lifetime_**
+          defines the *Request Key* lifetime in minutes, by default is 1 minute.
+
+	  The **_su_** (*substitute user*) option can be used by Admin users
+          to be identified as another existing API user at the TLP Web Service.
+      """
+      self._reset()
+      self.parameters['id'] = oid
+      if vhash != None: self.parameters['hash'] = vhash
+      if su != None: self.parameters['su'] = su
+      if use_req_key:
+          self._set_auth_parameters_request_key_api(req_key_lifetime, oid)
+      else:
+          self._set_auth_parameters_secret_key()
+      self._call("active_sessions")
 
     def generate_player_url(self, oid, author_id, author_conf, session_id=None, req_key_lifetime=1440, language=None, author_name=None, start=None, options=None):
       """ Returns a valid TLP Player URL.
